LoginUserRemoteDataSource class

Implemented types

Constructors

LoginUserRemoteDataSource(NetworkService networkService)

Properties

hashCode int
The hash code for this object.
no setterinherited
networkService NetworkService
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyLeave({required Map<String, dynamic> user}) Future<Either<AppException, Response>>
override
findAssetDetail({required Map<String, dynamic> user}) Future<Either<AppException, Response>>
override
isOTPEnabled({required String user}) Future<Either<AppException, Response>>
override
leaveList() Future<Either<AppException, Response>>
override
loginUser({required Map<String, dynamic> user}) Future<Either<AppException, Response>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited