DispatchExecutiveDataSourceImpl class

Inheritance

Constructors

DispatchExecutiveDataSourceImpl(NetworkService networkService)

Properties

hashCode int
The hash code for this object.
no setterinherited
networkService NetworkService
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getToteDetail(Map<String, dynamic> data) Future<Either<AppException, Response>>
override
markToShip(Map<String, dynamic> data) Future<Either<AppException, Response>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
searchBatchcode(Map<String, dynamic> data) Future<Either<AppException, Response>>
override
toString() String
A string representation of this object.
inherited
viewOrder(Map<String, dynamic> data) Future<Either<AppException, Response>>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited